Transient Simulation in water Networks (TSNet)
==============================================

.. figure:: figures/highlight.png
   :width: 600
   :alt: highlight


TSNet is a Python package designed to perform transient simulation in water
distribution networks. The software includes capability to:

* Create transient models based on EPANET INP files
* Operate valves and pumps
* Add disruptive events including pipe bursts and leaks
* Model open and closed surge tanks
* Choose between steady,quasi-steady, and unsteady friction models
* Perform transient simulation using Method of characteristics (MOC) techniques
* Visualize results

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
